@@ -17,11 +17,11 @@ Dancer Plugin to control validity of route from a Spore configuration file
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =cut
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 =head1 SYNOPSIS
 
@@ -174,7 +174,7 @@ register 'check_spore_definition' => sub {
 
 #        my $all_route_pattern = $req->{_route_pattern};
 #my $detail_route_pattern =  split /?/, $route_pattern;
-        #$path_validation = _load_path_validation() if !$path_validation;
+        $path_validation = _load_path_validation() if !$path_validation;
         unless (defined( $path_validation->{method}->{$req->method()}) || uc($req->method()) eq "OPTIONS" )
         {
           my $req_method = $req->method();
